@@ -1,18 +1,18 @@
-#' @rdname statTLRline
+#' @rdname  constant-line
+#' @aliases StatLline
 #' @export
 stat_Lline <- function (mapping = NULL, data = NULL, geom = "Lline", position = "identity", Lintercept, ...) {
   StatLline$new(mapping = mapping, data = data, geom = geom, position = position, Lintercept = Lintercept, ...)
 }
 
-#' @rdname undocumented
 StatLline <- proto(ggint$Stat, {
   objname <- "Lline"
   calculate <- function(., data, scales, Lintercept = NULL, ...) {
     data <- ggint$compute_intercept(data, Lintercept, "L") 
     
-    lc <- get_last_coord()
-    if(!inherits(lc,"ternary")){stop("Lline only relevant for ternary coordinates")}
+    tern_stop(.$objname)
     
+    lc <- get_last_coord()
     Tlim <- lc$limits$T; Tlim <- ifthenelse(!is.numeric(Tlim),c(1,0),Tlim)
     Llim <- lc$limits$L; Llim <- ifthenelse(!is.numeric(Llim),c(1,0),Llim)
     Rlim <- lc$limits$R; Rlim <- ifthenelse(!is.numeric(Rlim),c(1,0),Rlim)
