@@ -1,17 +1,18 @@
-#' @rdname statTLRline
+#' @rdname constant-line
+#' @aliases StatRline
 #' @export
 stat_Rline <- function (mapping = NULL, data = NULL, geom = "Rline", position = "identity", Rintercept, ...) {
   StatRline$new(mapping = mapping, data = data, geom = geom, position = position, Rintercept = Rintercept, ...)
 }
 
-#' @rdname undocumented
 StatRline <- proto(ggint$Stat, {
   objname <- "Rline"
   calculate <- function(., data, scales, Rintercept = NULL, ...) {
     data <- ggint$compute_intercept(data, Rintercept, "R") 
     
+    tern_stop(.$objname)
+    
     lc <- get_last_coord()
-    if(!inherits(lc,"ternary")){stop("Rline only relevant for ternary coordinates")}
     
     Tlim <- lc$limits$T; Tlim <- ifthenelse(!is.numeric(Tlim),c(1,0),Tlim)
     Llim <- lc$limits$L; Llim <- ifthenelse(!is.numeric(Llim),c(1,0),Llim)
