@@ -1,17 +1,18 @@
-#' @rdname statTLRline
+#' @rdname constant-line
+#' @aliases StatTline
 #' @export
 stat_Tline <- function (mapping = NULL, data = NULL, geom = "Tline", position = "identity", Tintercept, ...) {
   StatTline$new(mapping = mapping, data = data, geom = geom, position = position, Tintercept = Tintercept, ...)
 }
 
-#' @rdname undocumented
 StatTline <- proto(ggint$Stat, {
   objname <- "Tline"
   calculate <- function(., data, scales, Tintercept = NULL, ...) {
     data <- ggint$compute_intercept(data, Tintercept, "T") 
     
+    tern_stop(.$objname)
+    
     lc <- get_last_coord()
-    if(!inherits(lc,"ternary")){stop("Tline only relevant for ternary coordinates")}
     
     Tlim <- lc$limits$T; Tlim <- ifthenelse(!is.numeric(Tlim),c(1,0),Tlim)
     Llim <- lc$limits$L; Llim <- ifthenelse(!is.numeric(Llim),c(1,0),Llim)
