@@ -1,12 +1,4 @@
-.tern_clockwise <- function(x){
-  if(!is.logical(x)){x=FALSE}
-  coord <- get_last_coord()
-  if(!inherits(coord,"ternary")){
-    coord <- coord_tern()
-  }
-  coord$clockwise=x
-  coord
-}
+.tern_clockwise <- function(x){theme(axis.tern.clockwise=x)}
 
 #' Direction of Ternary Rotation
 #' 
@@ -36,4 +28,25 @@ tern_anticlockwise    <- function(){.tern_clockwise(FALSE)}
 #'                   geom_point() + 
 #'                   tern_counterclockwise()
 #' @export
-tern_counterclockwise <- function(){.tern_clockwise(FALSE)}
\ No newline at end of file
+tern_counterclockwise <- function(){.tern_clockwise(FALSE)}
+
+#' Direction of Ternary Rotation
+#' 
+#' \code{theme_clockwise} is an alias for \code{tern_clockwise}
+#' @rdname ternary_clockwise
+#' @export
+theme_clockwise <- function(){tern_clockwise()}
+
+#' Direction of Ternary Rotation
+#' 
+#' \code{theme_anticlockwise} is an alias for \code{tern_anticlockwise}
+#' @rdname ternary_clockwise
+#' @export
+theme_anticlockwise <- function(){tern_anticlockwise()}
+
+#' Direction of Ternary Rotation
+#' 
+#' \code{theme_counterclockwise} is an alias for \code{tern_counterclockwise}
+#' @rdname ternary_clockwise
+#' @export
+theme_counterclockwise <- function(){tern_counterclockwise()}
